FontPicker constructor

const FontPicker({
  1. Key? key,
  2. String? selectedFont,
  3. required ValueChanged<String> onFontSelected,
  4. required List<String> availableFonts,
  5. String previewText = 'The quick brown fox jumps over the lazy dog',
  6. double previewFontSize = 16,
})

Implementation

const FontPicker({
  super.key,
  this.selectedFont,
  required this.onFontSelected,
  required this.availableFonts,
  this.previewText = 'The quick brown fox jumps over the lazy dog',
  this.previewFontSize = 16,
});