Font class

Available extensions
Annotations
  • @Dataclass.new()

Constructors

Font({FontWeight weight = FontWeight.normal, FontStyle style = FontStyle.normal, String family = "Arial", int size = 16})

Properties

family String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
style FontStyle
getter/setter pair
weight FontWeight
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textStyle({Color? color, Color? backgroundColor}) TextStyle

Available on Font, provided by the FontHelper extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited